@@ -45,6 +45,7 @@ def test_opt_compute_potential(
 def test_opt_translate_atoms_along_vector(
     optimizer, molecule, position_matrix, position_matrix3
 ):
+    molecule = molecule.with_position_matrix(position_matrix)
     new_molecule = optimizer._translate_atoms_along_vector(
         mol=molecule,
         atom_ids=(3, 4, 5),
@@ -55,10 +56,11 @@ def test_opt_translate_atoms_along_vector(
         new_molecule.get_position_matrix(),
     ))
     new_molecule = optimizer._translate_atoms_along_vector(
-        mol=molecule,
+        mol=new_molecule,
         atom_ids=(3, 4, 5),
         vector=np.array([0, -5, 0])
     )
+    print(position_matrix, new_molecule.get_position_matrix())
     assert np.all(np.equal(
         position_matrix,
         new_molecule.get_position_matrix(),
@@ -73,18 +75,15 @@ def test_opt_test_move(optimizer):
 def test_opt_get_result(optimizer, molecule):
     original_pos_mat = molecule.get_position_matrix()
     subunits = molecule.get_subunits(bond_pair_ids=((0, 3), ))
-    results = optimizer.get_result(
+    mol, results = optimizer.get_result(
         mol=molecule,
         bond_pair_ids=((0, 3), ),
         subunits=subunits,
     )
 
-    assert results.get_step_count() == 99
-    assert len(tuple(results.get_steps_properties())) == 1
-
     final_bond_length = np.linalg.norm(
         optimizer._get_bond_vector(
-            position_matrix=results.get_final_position_matrix(),
+            position_matrix=results.get_position_matrix(),
             bond_pair=(0, 3),
         ),
     )
@@ -96,7 +95,7 @@ def test_opt_get_result(optimizer, molecule):
     for bond in molecule.get_bonds():
         if (bond.get_atom1_id(), bond.get_atom2_id()) != (0, 3):
             test = get_atom_distance(
-                position_matrix=results.get_final_position_matrix(),
+                position_matrix=results.get_position_matrix(),
                 atom1_id=bond.get_atom1_id(),
                 atom2_id=bond.get_atom2_id(),
             )
@@ -111,7 +110,7 @@ def test_opt_get_result(optimizer, molecule):
 def test_opt_get_trajectory(optimizer, molecule):
     original_pos_mat = molecule.get_position_matrix()
     subunits = molecule.get_subunits(bond_pair_ids=((0, 3), ))
-    results = optimizer.get_trajectory(
+    mol, results = optimizer.get_trajectory(
         mol=molecule,
         bond_pair_ids=((0, 3), ),
         subunits=subunits,
